@@ -1,12 +1,10 @@
 from pathlib import Path
+from typing import Optional
+
 from magicgui import magicgui
-from pkg_resources import resource_filename
 from napari.qt.threading import thread_worker
 
-
-brainglobe_logo = resource_filename(
-    "cellfinder_napari", "resources/brainglobe.png"
-)
+from cellfinder_napari.utils import brainglobe_logo
 
 
 def train():
@@ -75,12 +73,22 @@ def train():
             value=DEFAULT_PARAMETERS["Pretrained_model"],
             choices=PRETRAINED_MODELS,
         ),
-        Continue_training=dict(value=DEFAULT_PARAMETERS["Continue_training"]),
+        Continue_training=dict(
+            value=DEFAULT_PARAMETERS["Continue_training"],
+            label="Continue training",
+        ),
         Augment=dict(value=DEFAULT_PARAMETERS["Augment"]),
         Tensorboard=dict(value=DEFAULT_PARAMETERS["Tensorboard"]),
-        Save_weights=dict(value=DEFAULT_PARAMETERS["Save_weights"]),
-        Save_checkpoints=dict(value=DEFAULT_PARAMETERS["Save_checkpoints"]),
-        Save_progress=dict(value=DEFAULT_PARAMETERS["Save_progress"]),
+        Save_weights=dict(
+            value=DEFAULT_PARAMETERS["Save_weights"], label="Save weights"
+        ),
+        Save_checkpoints=dict(
+            value=DEFAULT_PARAMETERS["Save_checkpoints"],
+            label="Save checkpoints",
+        ),
+        Save_progress=dict(
+            value=DEFAULT_PARAMETERS["Save_progress"], label="Save progress"
+        ),
         Epochs=dict(value=DEFAULT_PARAMETERS["Epochs"]),
         Learning_rate=dict(
             value=DEFAULT_PARAMETERS["Learning_rate"], step=0.0001
@@ -105,8 +113,8 @@ def train():
         YAML_files: Path,
         Output_directory: Path,
         network_options,
-        Trained_model: Path,
-        Model_weights: Path,
+        Trained_model: Optional[Path],
+        Model_weights: Optional[Path],
         Model_depth: str,
         Pretrained_model: str,
         training_options,
@@ -132,9 +140,9 @@ def train():
             YAML files containing paths to training data
         Output_directory : Path
             Directory to save the output trained model
-        Trained_model : Path
+        Trained_model : Optional[Path]
             Existing pre-trained model
-        Model_weights : Path
+        Model_weights : Optional[Path]
             Existing pre-trained model weights
             Should be set along with "Model depth"
         Model_depth : str
@@ -168,13 +176,15 @@ def train():
             Fraction of training data to use for validation
         Number_of_free_cpus : int
             How many CPU cores to leave free
+        reset_button :
+            Reset parameters to default
         """
         if Trained_model == Path.home():
             Trained_model = None
         if Model_weights == Path.home():
             Model_weights = None
 
-        if YAML_files[0] == Path.home():
+        if YAML_files[0] == Path.home():  # type: ignore
             print("Please select a YAML file for training")
         else:
             worker = run_training(
@@ -204,6 +214,7 @@ def train():
         '<p><a href="https://docs.brainglobe.info/cellfinder/napari-plugin" style="color:gray;">Documentation</a></p>'
         '<p><a href="https://github.com/brainglobe/cellfinder-napari" style="color:gray;">Source</a></p>'
         '<p><a href="https://www.biorxiv.org/content/10.1101/2020.10.21.348771v2" style="color:gray;">Citation</a></p>'
+        "<p><small>For help, hover the cursor over each parameter.</small>"
     )
     widget.header.native.setOpenExternalLinks(True)
 
